@@ -5,6 +5,7 @@ VERSION="${1:-9}" # E.g: '9'
 IMAGE="${NAME}:${VERSION}"
 INSTALLROOT="/dev/shm/${IMAGE}"
 ARCH="x86_64"
+[ -x /usr/bin/pigz ] && GZIP=pigz || GZIP=gzip
 
 sudo rm -rf "${INSTALLROOT}"
 sudo mkdir -p "${INSTALLROOT}"
@@ -29,6 +30,6 @@ sudo rm -rf "${INSTALLROOT}"
 docker rmi -f "${IMAGE}"
 docker import "${FILE}" "${IMAGE}"
 
-pigz "${FILE}"
+${GZIP} "${FILE}"
 mkdir -p "${HOME}/tde/docker"
 mv -fv "${FILE}.gz" "${HOME}/tde/docker"
