@@ -1,8 +1,9 @@
 #!/bin/bash
 
 NAME="mageia32"
-VERSION="${1:-8}" # E.g: '26'
+VERSION="$1" # E.g: '26'
 IMAGE="${NAME}:${VERSION}"
+TAR="${NAME}-${VERSION}.tar"
 INSTALLROOT="/dev/shm/${IMAGE}"
 
 sudo rm -rf "${INSTALLROOT}"
@@ -12,8 +13,8 @@ setarch i686 sudo urpmi \
   --auto \
   bash vim urpmi mageia-release-common
 
-sudo tar -C "${INSTALLROOT}" -c . >"${IMAGE}.tar"
+sudo tar -C "${INSTALLROOT}" -c . >"${TAR}"
 sudo rm -rf "${INSTALLROOT}"
 
 docker rmi -f "${IMAGE}"
-docker import "${IMAGE}.tar" "${IMAGE}"
+docker import "${TAR}" "${IMAGE}"
