@@ -1,7 +1,7 @@
 #!/bin/bash -ex
 
 NAME="openmandriva"
-VERSION="${1:-5.0}" # E.g: '26'
+VERSION="${1:-6.0}" # E.g: '6.0'
 IMAGE="${NAME}:${VERSION}"
 TAR="${NAME}-${VERSION}.tar"
 INSTALLROOT="/dev/shm/${IMAGE}"
@@ -20,6 +20,8 @@ sudo dnf install \
   --repofrompath 'omv-updates,http://mirror.openmandriva.org/$releasever/repository/x86_64/main/updates/' \
    bash curl dnf vim
 
+sudo rm -rf "${INSTALLROOT}/var/cache/dnf"
+
 sudo tar -C "${INSTALLROOT}" -c . >"${TAR}"
 sudo rm -rf "${INSTALLROOT}"
 
