@@ -1,4 +1,4 @@
-#!/bin/bash -e
+#!/bin/bash -ex
 
 if [ "$(whoami)" != "root" ]; then
   sudo exec $0 $@
@@ -20,7 +20,7 @@ INSTALLROOT="/dev/shm/${IMAGE}"
 [ -x /usr/bin/pigz ] && GZIP=pigz || GZIP=gzip
 
 for dir in dev proc sys; do
-  if [ -d "${INSTALLROOT}/${dir}" ]; then
+  if [ -d "${INSTALLROOT}/${dir}" ] && grep "${INSTALLROOT}/${dir}" /proc/mounts; then
     umount "${INSTALLROOT}/${dir}"
   fi
 done
@@ -58,7 +58,6 @@ setarch i686 zypper --root "${INSTALLROOT}"  \
   glibc-extra \
   grep \
   gzip \
-  libpcre1 \
   libselinux1 \
   openSUSE-release \
   system-user-root \
@@ -77,12 +76,13 @@ done
 rm -rfv "${INSTALLROOT}/var/cache/zypp/packages/"*
 
 FILE="${IMAGE//\//_}.tar"
-tar -C "${INSTALLROOT}" -c . >"${FILE}"
+FILE="${FILE//:/_}"
+tar -C "${INSTALLROOT}" -c . >"/tmp/${FILE}"
 rm -rf "${INSTALLROOT}"
 
-docker rmi -f "${IMAGE}"
-docker import "${FILE}" "${IMAGE}"
+podman rmi -f "${IMAGE}"
+podman import "/tmp/${FILE}" "${IMAGE}"
 
-${GZIP} "${FILE}"
+${GZIP} "/tmp/${FILE}"
 mkdir -p "/home/${SUDO_USER}/tde/docker"
-mv -fv "${FILE}.gz" "/home/${SUDO_USER}/tde/docker"
+mv -fv "/tmp/${FILE}.gz" "/home/${SUDO_USER}/tde/docker"
