@@ -1,11 +1,12 @@
 #!/bin/bash -ex
 
 NAME="pclinuxos"
-VERSION="${1:-2024}" # E.g: '2020'
+VERSION="${1:-2025}" # E.g: '2020'
 IMAGE="${NAME}:${VERSION}"
 INSTALLROOT="/dev/shm/${IMAGE}"
 [ -x /usr/bin/pigz ] && GZIP=pigz || GZIP=gzip
 
+grep -qw "${INSTALLROOT}/dev/shm" /proc/mounts && sudo umount "${INSTALLROOT}/dev/shm"
 grep -qw "${INSTALLROOT}/dev" /proc/mounts && sudo umount "${INSTALLROOT}/dev"
 sudo rm -rf "${INSTALLROOT}"
 sudo mkdir -p "${INSTALLROOT}"
@@ -46,9 +47,9 @@ sudo chroot "${INSTALLROOT}" apt-get -y upgrade
 sudo umount "${INSTALLROOT}/dev/shm"
 sudo umount "${INSTALLROOT}/dev"
 
-docker rmi -f "${IMAGE}" || :
-sudo tar -C "${INSTALLROOT}" -c . | docker import - "${IMAGE}"
-docker run -ti --rm "${IMAGE}" ls -l
+podman rmi -f "${IMAGE}" || :
+sudo tar -C "${INSTALLROOT}" -c . | podman import - "${IMAGE}"
+podman run -ti --rm "${IMAGE}" ls -l
 sudo rm -rf "${INSTALLROOT}"
 
-docker image save "${IMAGE}" | ${GZIP} -9 >"${HOME}/tde/docker/${IMAGE}.tar.gz"
+podman image save "${IMAGE}" | ${GZIP} -9 >"${HOME}/tde/docker/${IMAGE}.tar.gz"
