@@ -4,7 +4,7 @@ DISTRIB="$1"
 TDE_VERSION="$2"
 ARCH="$3"
 
-[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.1.3"
+[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.1.5"
 [ -z "${ARCH}" ] && ARCH="x86_64"
 [ -x /usr/bin/podman ] && DOCKER=podman || DOCKER=docker
 
@@ -30,7 +30,7 @@ ${DOCKER} run -ti --rm \
   --name "${IMAGE//:/-}" \
   -v /dev/shm/${DOCKER}:/tmp:z \
   -u trinity \
-  --userns keep-id:uid=1000,gid=1000 \
+  --userns keep-id:uid="$(id -u)",gid="$(id -g)" \
   -e TMPPATH=/tmp \
   -e TDE_VERSION=${TDE_VERSION} \
   -e TDE_BRANCH=${TDE_BRANCH} \
